@@ -1,7 +1,7 @@
 """
 Type annotations for personalize-runtime service client.
 
-[Open documentation](./client.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html)
 
 Usage::
 
@@ -37,8 +37,8 @@ class Exceptions:
 
 class PersonalizeRuntimeClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.83/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
-    [Show boto3-stubs documentation](./client.md)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html)
     """
 
     meta: ClientMeta
@@ -46,8 +46,8 @@ class PersonalizeRuntimeClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.83/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#can_paginate)
         """
 
     def generate_presigned_url(
@@ -58,35 +58,37 @@ class PersonalizeRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.83/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#generate_presigned_url)
         """
 
     def get_personalized_ranking(
         self,
+        *,
         campaignArn: str,
         inputList: List[str],
         userId: str,
         context: Dict[str, str] = None,
         filterArn: str = None,
-        filterValues: Dict[str, str] = None,
+        filterValues: Dict[str, str] = None
     ) -> GetPersonalizedRankingResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.83/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
-        [Show boto3-stubs documentation](./client.md#get_personalized_ranking)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#get_personalized_ranking)
         """
 
     def get_recommendations(
         self,
+        *,
         campaignArn: str,
         itemId: str = None,
         userId: str = None,
         numResults: int = None,
         context: Dict[str, str] = None,
         filterArn: str = None,
-        filterValues: Dict[str, str] = None,
+        filterValues: Dict[str, str] = None
     ) -> GetRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.83/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
-        [Show boto3-stubs documentation](./client.md#get_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#get_recommendations)
         """
